@@ -6,8 +6,9 @@ use Carp qw( carp croak );
 use URI ();
 use Digest::MD5 ();
 
-our $VERSION = "0.06";
-our $Gravatar_Base = "http://www.gravatar.com/avatar/";
+our $VERSION = "0.10";
+our $AUTHORITY = "cpan:ASHLEY";
+our $Gravatar_Base = "https://gravatar.com/avatar/";
 
 sub new {
     my ( $class, $context, $instance_args ) = @_;
@@ -32,8 +33,8 @@ sub new {
         };
         $args->{email} || croak "Cannot generate a Gravatar URI without an email address";
         if ( $args->{size} ) {
-            $args->{size} >= 1 and $args->{size} <= 80
-                or croak "Gravatar size must be 1 .. 80";
+            $args->{size} >= 1 and $args->{size} <= 2048
+                or croak "Gravatar size must be 1 .. 2048";
         }
         if ( $args->{rating} ) {
             $args->{rating} =~ /\A(?:G|PG|R|X)\z/
@@ -42,15 +43,18 @@ sub new {
         if ( $args->{border} ) {
             carp "Border is deprecated! Dropping it.";
         }
-        
-        $args->{gravatar_id} = Digest::MD5::md5_hex($args->{email});
 
-        my $uri = URI->new($Gravatar_Base);
+        my $email = $args->{email};
+        s/\A\s+//, s/\s+\z// for $email;
+        $email = lc $email; # Might need to consider charset here or document consideration...
+        $args->{gravatar_id} = Digest::MD5::md5_hex($email);
+
+        my $uri = URI->new( $args->{base} || $Gravatar_Base );
         my @ordered = map { $_, $args->{$_} }
             grep $args->{$_},
             qw( gravatar_id rating size default );
         $uri->query_form(@ordered);
-        return $uri;
+        $uri;
     }
 }
 
@@ -58,15 +62,11 @@ sub new {
 
 __END__
 
-=head1 NAME
+=head1 Name
 
 Template::Plugin::Gravatar - Configurable TT2-based generation of Gravatar URLs from email addresses.
 
-=head1 VERSION
-
-0.06
-
-=head1 SYNOPSIS
+=head1 Synopsis
 
   [% USE Gravatar %]
   [% FOR user IN user_list %]
@@ -101,29 +101,29 @@ Template::Plugin::Gravatar - Configurable TT2-based generation of Gravatar URLs
   print end_html();
 
   __DATA__
-  [% USE Gravatar %] 
+  [% USE Gravatar %]
   [% FILTER html %]
    <img src="[% Gravatar( user ) | html %]"
      alt="[% user.name | html %]" />
   [% END %]
 
-=head1 DESCRIPTION
+=head1 Description
 
 Please see L<http://gravatar.com/site/implement/url> for more on the
 service interface and L<http://gravatar.com/> for information
 about Gravatars (globally recognized avatars) in general.
 
-All of the options supported in Gravatars--default, rating, and
-size--can be used here. The gravatar_id is generated from a given
+All of the options supported in GravatarsE<mdash>default, rating, and
+sizeE<mdash>can be used here. The C<gravatar_id> is generated from a given
 email.
 
-=head1 INTERFACE/SETTINGS
+=head1 Interface/Settings
 
 =head2 new
 
 Not called directly. Called when you C<USE> the plugin. Takes defaults
 from the template config hash and mixes them with any per template
-defaults. E.g.,
+defaults. E.g.E<ndash>
 
   [% USE Gravatar %]
   Use config arguments if any.
@@ -157,7 +157,9 @@ have a family friendly forum, for example, you might set it to "G."
 
 =item border (DEPRECATED)
 
-A hex color, e.g. FF00FF or F0F. Gravatar no longer does anything with these so we don't even pass them along. If included they will give a warning.
+A hex color, e.g. FF00FF or F0F. Gravatar no longer does anything with
+these so we don't even pass them along. If included they will give a
+warning.
 
 =item base (developer override)
 
@@ -173,10 +175,10 @@ optional variable is it would allow avatar hijacking.
 =back
 
 The only argument that must be given when you call the C<Gravatar>
-plugin is the email. Everything else -- rating, default image, border,
-and size -- can be set in three different places: the config, the
-C<USE> call, or the C<Gravatar> call. All three of the following
-produce the same Gravatar URL.
+plugin is the email. Everything elseE<mdash>rating, default image,
+border, and sizeE<mdash>can be set in three different places: the
+config, the C<USE> call, or the C<Gravatar> call. All three of the
+following produce the same Gravatar URL.
 
 =head2 Settings via config
 
@@ -232,50 +234,49 @@ Used for per URL control.
 =head2 Base URL (for developers only)
 
 You may also override the base URL for retrieving the Gravatars. It's
-set to use the service from www.gravatar.com. It can be overridden in
-the config or the C<USE>.
+set to use the service from L<https://gravatar.com/>. It can be
+overridden in the config or the C<USE>.
 
-=head1 DIAGNOSTICS
+=head1 Diagnostics
 
 Email is the only required argument. Croaks without it.
 
 Rating and size are also validated on each call. Croaks if an
 invalid size (like 0 or 100) or rating (like MA or NC-17).
 
-=head1 CONFIGURATION AND ENVIRONMENT
+=head1 Configuration AND ENVIRONMENT
 
 No configuration is necessary. You may use the configuration hash of
 your new template to pass default information like the default image
 location for those without Gravatars. You can also set it in the C<USE>
 call per template if needed.
 
-=head1 DEPENDENCIES (SEE ALSO)
+=head1 Dependencies (see also)
 
 L<Template>, L<Template::Plugin>, L<Carp>, L<Digest::MD5>, and
 L<URI::Escape>.
 
-http://www.gravatar.com/
+L<http://gravatar.com/>
 
-=head1 BUGS AND LIMITATIONS
+=head1 Bugs and Limitations
 
 None known. I certainly appreciate bug reports and feedback via
-C<bug-template-plugin-gravatar@rt.cpan.org>, or through the web
-interface at L<http://rt.cpan.org/>.
+L<https://github.com/pangyre/p5-template-plugin-gravatar/issues>.
 
-=head1 AUTHOR
+=head1 Author
 
 Ashley Pond V, C<< <ashley@cpan.org> >>.
 
-=head1 LICENSE
+=head1 License
 
-Copyright 2007-2009, Ashley Pond V.
+Copyright 2007-2016, Ashley Pond V.
 
 This program is free software; you can redistribute it and modify it
 under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>.
+See L<http://dev.perl.org/licenses/artistic.html>.
 
-=head1 SEE ALSO
+=head1 See Also
 
 L<Gravatar::URL> - standalone Gravatar URL generation.
 
